/*
 * Decompiled with CFR 0.152.
 */
package com.hst.taxService.service;

import com.hst.common.domain.BaseAppServiceDomain;
import com.hst.common.domain.TaxCommonReturnDomain;
import com.hst.common.service.BaseBusinessService;

public interface TaxCtais2CommonAppService
extends BaseBusinessService {
    public TaxCommonReturnDomain queryFppzjbxxcx(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryNsrfpjc(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryNsrfpyjxx(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryFpxs(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryFpyj(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryNsrFplgxx(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryFplgbdy(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryFplgbhs(BaseAppServiceDomain var1, String var2) throws Exception;

    public TaxCommonReturnDomain queryFpfskcxx(BaseAppServiceDomain var1, String var2) throws Exception;
}
